@@ -70,6 +70,16 @@ QString getObjDump()
     return env.value(QStringLiteral("OBJDUMP"), QStringLiteral("objdump"));
 }
 
+static
+QString getObjDumpFormat()
+{
+    if (env.isEmpty())
+        env = QProcessEnvironment::systemEnvironment();
+
+    return env.value(QStringLiteral("OBJDUMP_FORMAT"));
+}
+
+
 // parsing output of 'objdump'
 
 static Addr parseAddr(char* buf)
@@ -294,6 +304,7 @@ void InstrView::context(const QPoint & p)
         // remember width when hiding
         if (!_showHexCode)
             _lastHexCodeWidth = columnWidth(4);
+        // fixme: when showing, width may be wrong if not initially shown
         setColumnWidths();
     }
 }
@@ -460,12 +471,9 @@ void InstrView::setColumnWidths()
 #else
     header()->setResizeMode(4, QHeaderView::Interactive);
 #endif
-    if (_showHexCode) {
+    setColumnHidden(4, !_showHexCode);
+    if (_showHexCode)
         setColumnWidth(4, _lastHexCodeWidth);
-    }
-    else {
-        setColumnWidth(4, 0);
-    }
 }
 
 // compare functions for jump arrow drawing
@@ -528,20 +536,13 @@ void InstrView::refresh()
     clear();
     setColumnWidth(0, 20);
     setColumnWidth(1, 50);
-    setColumnWidth(2, _eventType2 ? 50:0);
-    setColumnWidth(3, 0);   // arrows, defaults to invisible
-    setColumnWidth(4, 0);   // hex code column
+    setColumnHidden(2, (_eventType2 == 0));
+    setColumnWidth(2, 50);
+    setColumnHidden(3, true); // arrows, defaults to invisible
+    setColumnHidden(4, true); // hex code column, defaults to invisible
     setColumnWidth(5, 50);  // command column
     setColumnWidth(6, 250); // arg column
 
-    // reset to automatic sizing to get column width
-#if QT_VERSION >= 0x050000
-    header()->setSectionResizeMode(4, QHeaderView::ResizeToContents);
-#else
-    header()->setResizeMode(4, QHeaderView::ResizeToContents);
-#endif
-
-
     if (_eventType)
         headerItem()->setText(1, _eventType->name());
     if (_eventType2)
@@ -589,6 +590,16 @@ void InstrView::refresh()
         return;
     }
 
+    if (_showHexCode) {
+        // make column visible and set to automatic sizing to get column width
+        setColumnHidden(4, false);
+#if QT_VERSION >= 0x050000
+        header()->setSectionResizeMode(4, QHeaderView::ResizeToContents);
+#else
+        header()->setResizeMode(4, QHeaderView::ResizeToContents);
+#endif
+    }
+
     // initialisation for arrow drawing
     // create sorted list of jumps (for jump arrows)
     _lowList.clear();
@@ -647,7 +658,6 @@ void InstrView::refresh()
 #else
         header()->setResizeMode(2, QHeaderView::Interactive);
 #endif
-        setColumnWidth(2, 0);
     }
 
     // reset to the original position - this is useful when the view
@@ -838,18 +848,19 @@ bool InstrView::fillInstrRange(TraceFunction* function,
 
     // call objdump synchronously
     QString objfile = dir + '/' + function->object()->shortName();
-    QStringList objdumpArgs = QStringList()
-                              << QStringLiteral("-C") << QStringLiteral("-d")
-                              << QStringLiteral("--start-address=0x%1").arg(dumpStartAddr.toString())
-                              << QStringLiteral("--stop-address=0x%1").arg(dumpEndAddr.toString())
-                              << objfile;
+    QString objdump_format = getObjDumpFormat();
+    if (objdump_format.isEmpty())
+        objdump_format = getObjDump() + " -C -d --start-address=0x%1 --stop-address=0x%2 %3";
+    QString objdumpCmd = objdump_format
+            .arg(dumpStartAddr.toString())
+            .arg(dumpEndAddr.toString())
+            .arg(objfile);
 
-    QString objdumpCmd = getObjDump() + " " + objdumpArgs.join(QStringLiteral(" "));
     qDebug("Running '%s'...", qPrintable(objdumpCmd));
 
     // and run...
     QProcess objdump;
-    objdump.start(getObjDump(), objdumpArgs);
+    objdump.start(objdumpCmd);
     if (!objdump.waitForStarted() ||
         !objdump.waitForFinished()) {
 
@@ -1117,10 +1128,12 @@ bool InstrView::fillInstrRange(TraceFunction* function,
         }
     }
 
-    if (arrowLevels())
+    if (arrowLevels()) {
+        setColumnHidden(3, false);
         setColumnWidth(3, 10 + 6*arrowLevels() + 2);
+    }
     else
-        setColumnWidth(3, 0);
+        setColumnHidden(3, true);
 
     if (noAssLines > 1) {
         // trace cost not matching code
